/*
 * IBM Confidential
 * OCO Source Materials
 * Rational ClearCase
 * (C) Copyright IBM Corp. 1991, 2007.  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */
/*
 * MFS sysgen parameters
 */

#include <sys/param.h>
#include <sys/vfs.h>
#include <sys/proc.h>

/*
 * Device number settings for the MVFS 
 * (Users shouldn't adjust them unless directed by a Rational tech support.)
 *
 * mvfs_major: The first major device number used by ncaexported vobs.
 * mvfs_majdynmax: The max number of major devices can be use by non-exported vobs.
 * mvfs_majfixmax: The max number of major devices can be use by ncaexported vobs.
 *   For example, if mvfs_major = 200, and mvfs_majfixmax = 10, the ncaexported
 *   vobs can use major device number range from 200, 201, ..., to 209.
 * mvfs_view_shift_bits: The number of view bits to be shifted, which is also the
 *   number of bits used for vob mounts in device numbers. Should be at least 8
 *   usually.
 *   On Solaris, the remaining bits for view_mask is: (18 - mvfs_view_shift_bits).
 */

dev_t mvfs_major = 200;

#ifdef ATRIA_SOLARIS510
/* 
 * On Solaris 10, we use bigger default settings for zone support.
 * By default:
 * The max number of non-exported vobs can be mounted simultaneously:
 *   mvfs_majdynmax * 2^mvfs_view_shift_bits /2 - 1 = 50*4096/2 - 1 = 102399
 * The max number of ncaexported vobs can be mounted simultaneously:
 *   mvfs_majfixmax * 2^mvfs_view_shift_bits /2 = 10*4096/2 = 20480
 * The view_mask contains 6 bits, so 2^6=64 view extended paths for each vob 
 * can have unique device numbers. 
 */
int mvfs_majdynmax = 50;
int mvfs_majfixmax = 10;
u_int mvfs_view_shift_bits = 12;
#else
/* 
 * By default (on earlier versions):
 * The max number of non-exported vobs can be mounted simultaneously:
 * mvfs_majdynmax * 2^mvfs_view_shift_bits /2 - 1 = 20*512/2 - 1 = 5119
 * The max number of ncaexported vobs can be mounted simultaneously:
 * mvfs_majfixmax * 2^mvfs_view_shift_bits /2 = 10*512/2 = 2560
 * view_mask contains 9 bits, so 2^9=512 view extended paths for each
 * vob can have unique device numbers.
 */
int mvfs_majdynmax = 20;
int mvfs_majfixmax = 10;
u_int mvfs_view_shift_bits = 9;
#endif

/*
 * Size of a proc struct so MFS is rev-independent when
 * additions made to the end of a proc structure.
 */

int mvfs_size_procstruct = sizeof(struct proc);

#include <sys/thread.h>
#include <sys/vnode.h>
#include <sys/user.h>

/*
 * MVFS_SET_UCRED - set cred of current process
 */

void
mvfs_set_ucred(cred)
cred_t *cred;
{
    curthread->t_cred = cred;
}

/*
 * MVFS_GET_UCDIR - get current dir of current process
 */

struct vnode *
mvfs_get_ucdir()
{
    return(u.u_cdir);
}

/*
 * MVFS_SET_UCDIR - set current dir of current process
 */

void
mvfs_set_ucdir(cdir)
struct vnode *cdir;
{
    u.u_cdir = cdir;
}

/*
 * MVFS_GET_URDIR - get root dir of current process
 */

struct vnode *
mvfs_get_urdir()
{
    return(u.u_rdir);
}

/*
 * MVFS_SET_URDIR - set root dir of current process
 */

void
mvfs_set_urdir(rdir)
struct vnode *rdir;
{
    u.u_rdir = rdir;
}

/*
 * MVFS_GET_UCOMM - get name of command of current process
 */

char *
mvfs_get_ucomm()
{
    return(u.u_comm);
}

/*
 * MVFS_GET_UCMASK - get current umask of current process
 */

int
mvfs_get_ucmask()
{
    return(u.u_cmask);
}

/*
 * MVFS_GET_URLIMIT - get rlimit for file size for current process.
 * Since Solaris 9, current file size limit moved to struct proc, 
 * called p_fsz_ctl, which is 64bit on both 32 and 64bit-kernel.
 */
#if defined (ATRIA_SOLARIS59) || defined(ATRIA_SOLARIS510)
rlim64_t
mvfs_get_urlimit()
{
    return curproc->p_fsz_ctl;
}
#else
rlim_t
mvfs_get_urlimit()
{
    return(u.u_rlimit[RLIMIT_FSIZE].rlim_cur);
}
#endif
